package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.vehicle.api.dto.CurrencyRecordDTO;
import com.chelvc.cloud.vehicle.api.dto.EarningsDTO;
import com.chelvc.cloud.vehicle.api.service.CurrencyRecordService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 收益记录接口
 *
 * @author liude
 * @date 2023/4/20
 */
@Validated
@RestController
@ResponseWrapping
public class CurrencyRecordController {
    @DubboReference
    private CurrencyRecordService currencyRecordService;

    /**
     * 用户收益记录列表查询
     *
     * @param type 类型：0-平台；1-用户；2-商户
     */
    @GetMapping("/listCurrencyRecord")
    public List<CurrencyRecordDTO> listCurrencyRecord(@NotNull(message = "查询类型不能为空") Integer type) {
        return this.currencyRecordService.listCurrencyRecord(type);
    }

    /**
     * 用户获取用户得总收益、本周收益、本月收益、可提现金额
     *
     * @param type 类型：0-平台；1-用户；2-商户
     */
    @GetMapping("/getCurrencyRecord")
    public EarningsDTO getCurrencyRecord(@NotNull(message = "查询类型不能为空") Integer type) {
        return this.currencyRecordService.getCurrencyRecord(type);
    }
}
